#!/usr/bin/env node
var __require = /* @__PURE__ */ ((x) => typeof require !== "undefined" ? require : typeof Proxy !== "undefined" ? new Proxy(x, {
  get: (a, b) => (typeof require !== "undefined" ? require : a)[b]
}) : x)(function(x) {
  if (typeof require !== "undefined")
    return require.apply(this, arguments);
  throw new Error('Dynamic require of "' + x + '" is not supported');
});

// src/cli.ts
import { program } from "commander";

// src/main.ts
import path from "path";
import * as glob from "glob";
import fs from "fs";

// src/util.ts
var regCustomProperty = /\s*-{2}[a-zA-F0-9-]+\s*:\s*[a-zA-Z0-9#\"\-\,\s\(\).]+\s*;\n*/g;
var getFinalOptions = (options2) => {
  return {
    include: options2.include || "**/*.?(css|scss|sass|less)",
    exclude: options2.exclude,
    output: options2.output || "./properties.ts"
  };
};
var toCamelCase = (target) => {
  return target.replace("--", "").replace(/^[A-Z]/, (m) => m.toLowerCase()).replace(/[-_ ./~ ]+([A-z0-9])/g, (m, $1) => $1.toUpperCase());
};

// src/main.ts
var _loadedSassPreprocessor;
var _loadedLessPreprocessor;
var main = async (options2) => {
  const finalOptions = getFinalOptions(options2);
  const filePaths = glob.sync(finalOptions.include, {
    ignore: finalOptions.exclude
  });
  let customProperties = /* @__PURE__ */ new Map();
  for (const filePath of filePaths) {
    try {
      const buffer = fs.readFileSync(filePath);
      const fileContent = buffer.toString();
      let customPropertyWithValues = null;
      if (filePath.endsWith(".scss") || filePath.endsWith(".sass")) {
        customPropertyWithValues = sass(filePath);
      } else if (filePath.endsWith(".less")) {
        customPropertyWithValues = await less(filePath, fileContent);
      } else if (filePath.endsWith(".css")) {
        customPropertyWithValues = fileContent.match(regCustomProperty);
      }
      if (!customPropertyWithValues) {
        continue;
      }
      customPropertyWithValues.map((customPropertyWithValue) => {
        const [customPropertyKeyWithWhitespace, customPropertyValue] = customPropertyWithValue.split(":");
        const customPropertyKey = customPropertyKeyWithWhitespace.replaceAll(
          /[\s\n]*/g,
          ""
        );
        if (!customProperties.has(customPropertyKey)) {
          customProperties.set(customPropertyKey, customPropertyValue);
        }
      });
    } catch (e) {
      console.log("e :>> ", e);
    }
  }
  fs.writeFileSync(
    path.resolve(finalOptions.output),
    generateOutputString(customProperties),
    {}
  );
};
var sass = (filePath) => {
  const sass2 = loadSassPreprocessor();
  const result = sass2.renderSync({
    file: filePath,
    includePaths: ["node_modules"]
  });
  return result.css.toString().match(regCustomProperty);
};
var less = async (filePath, fileContent) => {
  const less2 = loadLessPreprocessor();
  const result = await less2.render(fileContent, {
    paths: [path.dirname(filePath)]
  });
  return result.css.match(regCustomProperty);
};
var loadSassPreprocessor = () => {
  try {
    if (_loadedSassPreprocessor) {
      return _loadedSassPreprocessor;
    }
    const fallbackPaths = __require.resolve.paths?.("sass") || [];
    const resolved = __require.resolve("sass", {
      paths: [__dirname, ...fallbackPaths]
    });
    return _loadedSassPreprocessor = __require(resolved);
  } catch (e) {
    console.error(e);
    throw new Error(
      `Preprocessor dependency 'sass' not found. Did you install it?`
    );
  }
};
var loadLessPreprocessor = () => {
  try {
    if (_loadedLessPreprocessor) {
      return _loadedLessPreprocessor;
    }
    const fallbackPaths = __require.resolve.paths?.("less") || [];
    const resolved = __require.resolve("less", {
      paths: [__dirname, ...fallbackPaths]
    });
    return _loadedLessPreprocessor = __require(resolved);
  } catch (e) {
    console.error(e);
    throw new Error(
      `Preprocessor dependency 'less' not found. Did you install it?`
    );
  }
};
var generateOutputString = (customProperties) => {
  let outputString = "";
  for (const customProperty of customProperties) {
    outputString = `${outputString}/**
`;
    outputString = `${outputString} * ${customProperty[1].replaceAll(
      /[\n]*/g,
      ""
    )}
`;
    outputString = `${outputString} */
`;
    outputString = `${outputString}export const ${toCamelCase(
      customProperty[0]
    )} = "var(${customProperty[0]})"
`;
  }
  return outputString;
};

// src/cli.ts
program.option("-o, --output <path>", "output path.").option("-i, --include <path>", "include path to glob.").option("-e, --exclude <path>", "exclude path to glob.").parse(process.argv);
var options = program.opts();
main(options);
